@@ -237,6 +237,12 @@ def plot_graph(G, fname, format):
 
 class Data:
     filetypes = []
+    extra_hierarchies = []
+
+    def __new__(cls, *args, **kwargs):
+        from fastapi.encoders import ENCODERS_BY_TYPE
+        ENCODERS_BY_TYPE[cls] = lambda x: x.as_dict()
+        return super().__new__(cls)
 
     def __init__(self, rootdir: Union[Path, str] = None,
                  host: str = None, port=None, dbname=None,
@@ -256,9 +262,10 @@ class Data:
         self.hierarchy_graph.initialise()
         if self.filetypes:
             self.hierarchies = hierarchies_from_files(*self.filetypes, templates=True)
-            self.hierarchies.update({hh for h in self.hierarchies for hh in get_all_class_bases(h)})
         else:
             self.hierarchies = set()
+        self.hierarchies.update(set(self.extra_hierarchies))
+        self.hierarchies.update({hh for h in self.hierarchies for hh in get_all_class_bases(h)})
         self.class_hierarchies = {h.__name__: h for h in self.hierarchies}
         self.singular_hierarchies = {h.singular_name: h for h in self.hierarchies}  # type: Dict[str, Type[Hierarchy]]
         self.plural_hierarchies = {h.plural_name: h for h in self.hierarchies if h.plural_name != 'graphables'}
@@ -281,6 +288,12 @@ class Data:
         self.relative_names = dict(self.relative_names)
         self.plural_relative_names = {make_plural(name): name for name in self.relative_names}
 
+    def __repr__(self):
+        return f'<Data({self.user}@{self.host}[{self.dbname}]:{self.port}:{self.rootdir})>'
+
+    def as_dict(self):
+        return {'user': self.user, 'host': self.host, 'dbname': self.dbname, 'port': self.port, 'rootdir': self.rootdir}
+
     def __dir__(self) -> List[str]:
         neighbors = [i.plural_name for i in self.hierarchies]
         neighbors += [i.lower() for h in self.hierarchies for i in h.products_and_factors]
@@ -419,12 +432,12 @@ class Data:
         d['dbupdated'] = ['CREATE INDEX n_dbupdated FOR (n:Hierarchy) ON n.`_dbupdated`']
         return d
 
-    def apply_constraints(self):
+    def apply_constraints(self, silent=False):
         if not self.write_allowed:
             raise IOError(f"Writing is not allowed")
         templates = set()
         equivalencies = set()
-        for hier, qs in tqdm(self.make_constraints_cypher().items(), desc='applying constraints'):
+        for hier, qs in tqdm(self.make_constraints_cypher().items(), desc='applying constraints', disable=silent):
             if not qs:
                 templates.add(hier)
             for q in qs:
@@ -1083,12 +1096,22 @@ class Data:
         return all(self.is_singular_name(n) for n in pattern)
 
     def __getitem__(self, address):
+        if not isinstance(address, str):
+            raise KeyError(f"{self} cannot be indexed by integers.")
         try:
             return self.query.__getitem__(address)
         except (UserError, KeyError) as e:
             self.query.raise_error_with_suggestions(address, e)
 
     def __getattr__(self, item):
+        if item in ['keys', 'items', 'values']:
+            # catch fastapi jsonable_encoder requests for serialization
+            raise AttributeError(f"{self} has no attribute {item}")
+        if item.startswith('_'):
+            # query attributes are not allowed to start with '_'
+            # if we are here, then that means __getattribute__ has failed and we should fail here
+            # like a normal object
+            raise AttributeError(f"{self} has no attribute {item}")
         try:
             return self.query.__getattr__(item)
         except (UserError, KeyError) as e:
@@ -1159,4 +1182,9 @@ class Data:
             l = self._autosuggest(a, relative_to)
         string = '\n'.join([f'{i}. {s}' for i, s in enumerate(l, start=1)])
         msg = f"did you mean one of:\n{string}"
-        raise exception.__class__(f"{str(exception.args[0])}\n{msg}") from exception
\ No newline at end of file
+        raise exception.__class__(f"{str(exception.args[0])}\n{msg}") from exception
+
+    def _get_by_neo4j_id(self, neoid, plural_name):
+        from weaveio.readquery.functions import neo4j_id
+        q = self.query.__getattr__(plural_name)
+        return q[neo4j_id(q) == int(neoid)]
\ No newline at end of file
